@@ -7,6 +7,7 @@
 #include <memory>
 #include "blapi.h"
 #include "gtest/gtest.h"
+#include "json.h"
 #include "nss.h"
 #include "nss_scoped_ptrs.h"
 #include "pk11hpke.h"
@@ -224,156 +225,6 @@ class HpkeTest {
   }
 };
 
-// If we make a few assumptions about the file, parsing JSON can be easy.
-// This is not a full parser, it only works on a narrow set of inputs.
-class JsonReader {
- public:
-  JsonReader(const std::string &n) : buf_(), available_(0), i_(0) {
-    f_.reset(PR_Open(n.c_str(), PR_RDONLY, 00600));
-    EXPECT_TRUE(f_) << "error opening vectors from: " << n;
-    buf_[0] = 0;
-  }
-
-  void next() { i_++; }
-  uint8_t peek() {
-    TopUp();
-    return buf_[i_];
-  }
-  uint8_t take() {
-    uint8_t v = peek();
-    next();
-    return v;
-  }
-
-  // No input checking, overflow protection, or any safety.
-  // Returns 0 if there isn't a number here rather than aborting.
-  uint64_t ReadInt() {
-    SkipWhitespace();
-    uint8_t c = peek();
-    uint64_t v = 0;
-    while (c >= '0' && c <= '9') {
-      v = v * 10 + c - '0';
-      next();
-      c = peek();
-    }
-    return v;
-  }
-
-  // No input checking, no unicode, no escaping (not even \"), just read ASCII.
-  std::string ReadLabel() {
-    SkipWhitespace();
-    if (peek() != '"') {
-      return "";
-    }
-    next();
-
-    std::string s;
-    uint8_t c = take();
-    while (c != '"') {
-      s.push_back(c);
-      c = take();
-    }
-    SkipWhitespace();
-    EXPECT_EQ(take(), ':');
-    return s;
-  }
-
-  std::vector<uint8_t> ReadHex() {
-    SkipWhitespace();
-    uint8_t c = take();
-    EXPECT_EQ(c, '"');
-    std::vector<uint8_t> v;
-    c = take();
-    while (c != '"') {
-      v.push_back(JsonReader::Hex(c) << 4 | JsonReader::Hex(take()));
-      c = take();
-    }
-    return v;
-  }
-
-  bool NextItem(uint8_t h = '{', uint8_t t = '}') {
-    SkipWhitespace();
-    switch (uint8_t c = take()) {
-      case ',':
-        return true;
-      case '{':
-      case '[':
-        EXPECT_EQ(c, h);
-        SkipWhitespace();
-        if (peek() == t) {
-          next();
-          return false;
-        }
-        return true;
-      case '}':
-      case ']':
-        EXPECT_EQ(c, t);
-        return false;
-      default:
-        ADD_FAILURE() << "Unexpected '" << c << "'";
-    }
-    return false;
-  }
-
-  void SkipValue() {
-    uint8_t c = take();
-    if (c == '"') {
-      do {
-        c = take();
-      } while (c != '"');
-    } else if (c >= '0' && c <= '9') {
-      c = peek();
-      while (c >= '0' && c <= '9') {
-        next();
-        c = peek();
-      }
-    } else {
-      ADD_FAILURE() << "No idea how to skip'" << c << "'";
-    }
-  }
-
- private:
-  void TopUp() {
-    if (available_ > i_) {
-      return;
-    }
-    i_ = 0;
-    if (!f_) {
-      return;
-    }
-    PRInt32 res = PR_Read(f_.get(), buf_, sizeof(buf_));
-    if (res > 0) {
-      available_ = static_cast<size_t>(res);
-    } else {
-      available_ = 1;
-      f_.reset(nullptr);
-      buf_[0] = 0;
-    }
-  }
-
-  void SkipWhitespace() {
-    uint8_t c = peek();
-    while (c && (c == ' ' || c == '\t' || c == '\r' || c == '\n')) {
-      next();
-      c = peek();
-    }
-  }
-
-  // This only handles lowercase.
-  uint8_t Hex(uint8_t c) {
-    if (c >= '0' && c <= '9') {
-      return c - '0';
-    }
-    EXPECT_TRUE(c >= 'a' && c <= 'f');
-    return c - 'a' + 10;
-  }
-
-  ScopedPRFileDesc f_;
-  uint8_t buf_[4096];
-  size_t available_;
-  size_t i_;
-};
-
 struct HpkeEncryptVector {
   std::vector<uint8_t> pt;
   std::vector<uint8_t> aad;
@@ -382,7 +233,7 @@ struct HpkeEncryptVector {
   static std::vector<HpkeEncryptVector> ReadVec(JsonReader &r) {
     std::vector<HpkeEncryptVector> all;
 
-    while (r.NextItem('[', ']')) {
+    while (r.NextItemArray()) {
       HpkeEncryptVector enc;
       while (r.NextItem()) {
         std::string n = r.ReadLabel();
@@ -414,7 +265,7 @@ struct HpkeExportVector {
   static std::vector<HpkeExportVector> ReadVec(JsonReader &r) {
     std::vector<HpkeExportVector> all;
 
-    while (r.NextItem('[', ']')) {
+    while (r.NextItemArray()) {
       HpkeExportVector exp;
       while (r.NextItem()) {
         std::string n = r.ReadLabel();
@@ -459,15 +310,12 @@ struct HpkeVector {
                                     const std::vector<uint8_t> &pk) {
     // Only X25519 format.
     std::vector<uint8_t> v(105);
-    v.assign({
-        0x30, 0x67, 0x02, 0x01, 0x00, 0x30, 0x14, 0x06, 0x07, 0x2a, 0x86, 0x48,
-        0xce, 0x3d, 0x02, 0x01, 0x06, 0x09, 0x2b, 0x06, 0x01, 0x04, 0x01, 0xda,
-        0x47, 0x0f, 0x01, 0x04, 0x4c, 0x30, 0x4a, 0x02, 0x01, 0x01, 0x04, 0x20,
-    });
+    v.assign({0x30, 0x67, 0x02, 0x01, 0x00, 0x30, 0x14, 0x06, 0x07,
+              0x2a, 0x86, 0x48, 0xce, 0x3d, 0x02, 0x01, 0x06, 0x09,
+              0x2b, 0x06, 0x01, 0x04, 0x01, 0xda, 0x47, 0x0f, 0x01,
+              0x04, 0x4c, 0x30, 0x4a, 0x02, 0x01, 0x01, 0x04, 0x20});
     v.insert(v.end(), sk.begin(), sk.end());
-    v.insert(v.end(), {
-                          0xa1, 0x23, 0x03, 0x21, 0x00,
-                      });
+    v.insert(v.end(), {0xa1, 0x23, 0x03, 0x21, 0x00});
     v.insert(v.end(), pk.begin(), pk.end());
     return v;
   }
@@ -476,7 +324,7 @@ struct HpkeVector {
     std::vector<HpkeVector> all_tests;
     uint32_t test_id = 0;
 
-    while (r.NextItem('[', ']')) {
+    while (r.NextItemArray()) {
       HpkeVector vec = {0};
       uint32_t fields = 0;
       enum class RequiredFields {
